// Copyright 2017-2025 WIT.COM Inc. All rights reserved.
// Use of this source code is governed by the GPL 3.0

package main

import (
	"embed"
	"os"
	"time"

	"go.wit.com/dev/alexflint/arg"
	"go.wit.com/lib/protobuf/forgepb"
	"go.wit.com/lib/protobuf/zoopb"
	"go.wit.com/log"
)

var VERSION string
var BUILDTIME string

//go:embed resources/*
var resources embed.FS

func main() {
	var pp *arg.Parser
	pp = arg.MustParse(&argv)

	if pp == nil {
		pp.WriteHelp(os.Stdout)
		os.Exit(0)
	}

	if argv.Daemon {
		// turn off timestamps for STDOUT (systemd adds them)
		log.DaemonMode(true)
	}

	me = new(stuff)
	me.urlbase = "http://zookeeper.grid.wit.com:8080"
	if argv.URL != "" {
		log.Info("USING ARGV URL:", argv.URL)
		me.urlbase = argv.URL
	}

	me.pollDelay = 3 * time.Second
	me.failcountmax = 20 // die every minute if zookeeper can't be found

	// me.machine.ConfigLoad()

	me.forge = forgepb.InitPB()
	me.machine = zoopb.InitMachine()

	go NewWatchdog()

	startHTTP()
}
